@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -7,7 +8,7 @@ class MessageComment:
     default_attributes = {
         'id': None,     # int64 - Message Comment ID
         'body': None,     # string - Comment body.
-        'reactions': None,     # array - Reactions to this comment.
+        'reactions': None,     # Reactions to this comment.
         'user_id': None,     # int64 - User ID.  Provide a value of `0` to operate the current session's user.
     }
 
@@ -74,7 +75,7 @@ class MessageComment:
 
 # Parameters:
 #   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   message_id (required) - int64 - Message comment to return comments for.
 def list(params = None, options = None):
